Skip to contents

Parallelised version of rWCVP::wcvp_match_names() to check plant taxonomic names against the World Checklist of Vascular Plants (WCVP), using future.apply::future.apply().

Usage

wcvp_match_names_parallel(
  df = NULL,
  name_col = NULL,
  author_col = NULL,
  fuzzy = TRUE,
  plan = "multisession",
  cores = 1,
  ...
)

Arguments

df

Data frame containing taxonomic names to be matched against WCVP.

name_col

Character. The column in 'df' containing the taxon names for matching.

author_col

Character. The column in 'df' that has the name authority, to aid matching. Set to NULL to match with no author string.

fuzzy

Logical; whether or not fuzzy matching should be used for names that could not be matched exactly.

plan

Character. Name of a future::plan() to be used for parallelisation. Recommended plan is "multisession". Use "sequential" for non-parallel processing.

cores

Number of cores to use in parallel.

...

Further arguments to be passed to rWCVP::wcvp_match_names()

Value

A data frame

Examples

if (FALSE) { # \dontrun{
df <- data.frame(taxon = c("Laurus nobilis", "Laurus nobilis", "Laurus nobili"),
                  author = c(NA, "L.", NA))
out <- wcvp_match_names_parallel(df, name_col = "taxon", author_col = "author",
  cores = 3)
} # }