Skip to contents

This function tries to resolve automatically the cases of multiple matches found after running a vector of taxonomic names against the World Checklist of Vascular Plants (WCVP).

Usage

wcvp_resolve_multiple_matches(df = NULL, name_col = NULL)

Arguments

df

Data frame with matching results, as produced by rWCVP::wcvp_match_names() or wcvp_match_names_parallel()

name_col

Character. Name of the column in 'df' containing the taxon names.

Value

A data frame

See also

https://matildabrown.github.io/rWCVP/articles/redlist-name-matching.html

Author

Adapted from rWCVP vignette

Examples

if (FALSE) { # \dontrun{
df <- data.frame(taxon = "Acacia dealbata")
matching <- wcvp_match_names_parallel(df, name_col = "taxon")
out <- wcvp_resolve_multiple_matches(matching, name_col = "taxon")
} # }